@@ -31,7 +31,7 @@
 #
 #	- go tell FreshMeat.net about it!
 #
-#ident "@(#)smail:RELEASE-3_2_0_119:mkRelease.sh,v 1.9 2004/08/18 08:23:26 woods Exp"
+#ident "@(#)smail:RELEASE-3_2_0_120:mkRelease.sh,v 1.10 2004/08/27 06:57:51 woods Exp"
 
 # NOTE: must be run from within an up-to-date CVS working directory
 
@@ -87,11 +87,6 @@ if [ "$(echo /usr/pkgsrc/mail/smail/patches/p*)" != '/usr/pkgsrc/mail/smail/patc
 	exit 1
 fi
 
-if [ $(cd /usr/pkgsrc/mail/smail && make show-var VARNAME=DISTNAME) != smail-${VERSION} ]; then
-	echo "$0: you haven't updated pkgsrc/mail/smail for smail-${VERSION} yet!" 1>&2
-	exit 1
-fi
-
 #
 #	NOTICE!!!  At this point we're "committed"!
 #
@@ -136,7 +131,7 @@ cvs export -kv -r ${TAG} -d smail-${VERSION} m-smail || exit 1
 cp ${OPWD}/ChangeLog-${VERSION} smail-${VERSION}/ || exit 1
 cp ${OPWD}/RELEASE-${VERSION} smail-${VERSION}/ || exit 1
 
-mv ${OPWD}/RELEASE-${VERSION} smail-${VERSION}-README.FIRST || exit 1
+cp ${OPWD}/RELEASE-${VERSION} smail-${VERSION}-README.FIRST || exit 1
 
 pax -w -z -f ${ARCHIVE_DIR}/smail-${VERSION}.tar.gz smail-${VERSION} || exit 1
 
@@ -150,6 +145,15 @@ rm -f ${DISTFILES}/smail-${PREV}.tar.gz ${DISTFILES}/smail-*-Pre-*.tar.gz
 
 (
 	cd /usr/pkgsrc/mail/smail
+	ed Makefile <<_EOF_
+,s/^DISTNAME/#DISTNAME/p
+1
+/^DISTNAME =	smail-[0-9.]*$/p
+s/smail-[0-9.]*$/smail-${VERSION}/p
+s/^#*//p
+w
+q
+_EOF_
 	make makesum mps
 )
 
@@ -163,6 +167,7 @@ cd ${ARCHIVE_DIR} || exit 1
 
 # leave the old README.FIRST
 # XXX if making BETA then should leave whatever old RELEASE points to
+#
 rm smail-${PREV}.tar.gz smail-${PREV}-README smail-${PREV}.ChangeLog smail-*-${PREV}.diffs.gz
 
 FILES="smail-${VERSION}-README.FIRST smail-${VERSION}-README smail-${VERSION}.tar.gz smail-${VERSION}.ChangeLog smail-${PREV}-${VERSION}.diffs.gz smail-pkgsrc.shar"
@@ -181,23 +186,23 @@ ln -s smail-${VERSION}.tar.gz smail.tar.gz
 
 echo rm README-${TYPE}
 echo ln -s smail-${VERSION}-README README-${TYPE}
-rm README-${TYPE}
-ln -s smail-${VERSION}-README README-${TYPE}
+rm smail-README-${TYPE}
+ln -s smail-${VERSION}-README smail-README-${TYPE}
 
 echo rm README.FIRST-${TYPE}
 echo ln -s smail-${VERSION}-README.FIRST README.FIRST-${TYPE}
-rm README.FIRST-${TYPE}
-ln -s smail-${VERSION}-README.FIRST README.FIRST-${TYPE}
+rm smail-README.FIRST-${TYPE}
+ln -s smail-${VERSION}-README.FIRST smail-README.FIRST-${TYPE}
 
 echo rm README
 echo ln -s smail-${VERSION}-README README
-rm README
-ln -s smail-${VERSION}-README README
+rm smail-README
+ln -s smail-${VERSION}-README smail-README
 
 echo rm README.FIRST
 echo ln -s smail-${VERSION}-README.FIRST README.FIRST
-rm README.FIRST
-ln -s smail-${VERSION}-README.FIRST README.FIRST
+rm smail-README.FIRST
+ln -s smail-${VERSION}-README.FIRST smail-README.FIRST
 
 # XXX if making a PATCH or a RELEASE then remove old BETA links...
 
