@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_119:addr.c,v 1.68 2004/08/23 23:18:55 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_120:addr.c,v 1.69 2004/08/27 06:46:17 woods Exp"
  */
 
 /*
@@ -250,7 +250,7 @@ preparse_address_1(address, error, rest)
 
 
 /*
- * parse_address - extract a target and remainder from an address
+ * parse_address - destructively "extract" a target and remainder from an address
  *
  * using the rules in section 3.2 of the mailer.design document,
  * extract a target and a remainder from an address.
@@ -285,7 +285,7 @@ preparse_address_1(address, error, rest)
  * inputs:
  *	address	- string containing the address to be parsed
  *	target	- where to store pointer to computed destination host
- *	remainder - where to store pointer to computed remainder
+ *	remainder - where to store pointer to computed remainder (or error)
  *
  * outut:
  *	return the address form as described in the above table.  Also,
@@ -312,8 +312,8 @@ preparse_address_1(address, error, rest)
  *		 parses of remainder addresses may use the RFC1123
  *		 precedence interpretation of the % operator.
  *
- * NOTE:  address will be overwritten unless it is in local form, or
- *	  a target and remainder are not returned.
+ * NOTE:  address will be modified unless it is in local form, or
+ *	  unless an error occurs.
  *
  * calls: address_token, back_address_token
  * called by: build_uucp_route
@@ -374,7 +374,7 @@ parse_address(address, target, remainder, flagp)
 	    int retval = (*ap == ',' ? RFC_ROUTE : RFC_ENDROUTE);
 
 	    if (target) {
-		*ap++ = '\0';		/* null terminate target */
+		*ap++ = '\0';			/* NUL-terminate target */
 		*remainder = ap;
 		if (check_target_and_remainder(target, remainder, retval) == FAIL) {
 		    return FAIL;
@@ -418,7 +418,7 @@ parse_address(address, target, remainder, flagp)
 	    *flagp |= FOUND_MAILBOX;
 	}
 	if (target) {
-	    *last_tokens = '\0';
+	    *last_tokens = '\0';	/* NUL-terminate previous tokens */
 	    *target = last_tokens+1;
 	    *remainder = ap;
 	    if (check_target_and_remainder(target, remainder, MAILBOX) == FAIL) {
@@ -569,7 +569,17 @@ check_target_and_remainder(targetp, remainderp, form)
     int c;
     char *p;
 
-    DEBUG3(DBG_ADDR_HI, "check_target_and_remainder(): hostname='%v', mailbox='%v', form=%d\n", *targetp, *remainderp, form);
+    DEBUG3(DBG_ADDR_HI, "check_target_and_remainder(): hostname='%v', mailbox='%v', form=%s\n",
+	   *targetp,
+	   *remainderp,
+	   (form == RFC_ROUTE) ? "RFC_ROUTE" :
+	   (form == RFC_ENDROUTE) ? "RFC_ENDROUTE" :
+	   (form == MAILBOX) ? "MAILBOX" :
+	   (form == UUCP_ROUTE) ? "UUCP_ROUTE" :
+	   (form == PCT_MAILBOX) ? "PCT_MAILBOX" :
+	   (form == LOCAL) ? "LOCAL" :
+	   (form == BERKENET) ? "BERKENET" :
+	   (form == DECNET) ? "DECNET" : "<bad-form!>");
     /*
      * first check the remainder...
      *
@@ -655,7 +665,7 @@ check_target_and_remainder(targetp, remainderp, form)
 	 *	XXX some validation really should be done on the remainer in
 	 *	non-MAILBOX forms too!!!
 	 */
-	DEBUG3(DBG_ADDR_LO, "check_target_and_remainder(%v, %v): not checking form=%d localpart.\n", *targetp, *remainderp, form);
+	DEBUG2(DBG_ADDR_LO, "check_target_and_remainder(%v, %v): not checking non-MAILBOX form in localpart.\n", *targetp, *remainderp);
      }
     /*
      * now check the target...
