@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_119:main.c,v 1.113 2004/08/23 23:20:54 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_120:main.c,v 1.114 2004/08/27 06:52:47 woods Exp"
  */
 
 /*
@@ -563,6 +563,11 @@ main(argc, argv)
     parse_grade_range(runq_grades, &min_runq_grade, &max_runq_grade);
     parse_grade_range(delivery_grades, &min_delivery_grade, &max_delivery_grade);
 
+    /* check any cmd-line sender address, now that we know our hostnames */
+    if (sender) {
+	check_sender(FALSE);
+    }
+
     /*
      * XXX we don't need to do these for all modes, only those that could
      * create a spool file, but for now....
@@ -1129,11 +1134,12 @@ reset_hit_table()
 void
 process_args(args, restrict)
     register char **args;		/* vector of arguments */
-    int restrict;                       /* enforce rsmtp restrictions */
+    int restrict;                       /* enforce rsmtp restrictions
+					 * (i.e. handling command-line from
+					 * main()) */
 {
     struct addr *cur;			/* temp addr list entry */
     char *arg;				/* single string from args */
-    char *error;			/* error message */
     char *newsender;			/* temp for process sender */
     int do_options = TRUE;		/* set TRUE until we see '--' */
     static char *end_arg = "";		/* trigger to swallow rest of arg */
@@ -1388,7 +1394,6 @@ process_args(args, restrict)
 		    newsender = *args++;
 		    panic_if_null(newsender, "f");
 		}
-
 		/*
 		 * don't use this sender if it has been determined that
 		 * the local originator of mail is not a user expected
@@ -1396,7 +1401,8 @@ process_args(args, restrict)
 		 */
 		if (sender_is_trusted) {
 		    sender = newsender;
-		    /* special form of sender for SMTP error mail */
+
+		    /* adjust for normal and magic null-return path sender */
 		    if (EQ(sender, "<>")) {
 			sender = "MAILER-DAEMON";
 			error_sender = TRUE;
@@ -1405,41 +1411,6 @@ process_args(args, restrict)
 			sender = "MAILER-DAEMON";
 			error_sender = TRUE;
 			islocal = TRUE;
-		    } else {
-			char *target;
-			int sender_type;
-
-			newsender = preparse_address(sender, &error);
-			if (! newsender) {
-			    if (errfile) {
-				dprintf(errfile,
-					"%s: error in sender name '%v': %v",
-					program, sender, error);
-			    }
-			    sender = "MAILER-DAEMON";
-			    islocal = FALSE;
-			} else {
-			    sender_type = parse_address(newsender, &target, &error, (int *) NULL);
-			    switch (sender_type) {
-			    case FAIL:
-				if (errfile) {
-				    dprintf(errfile,
-					    "%s: error in sender name '%v': %v",
-					    program, sender, error);
-				}
-				islocal = TRUE; /* assumptions... */
-				sender = "MAILER-DAEMON";
-				break;
-			    case LOCAL:
-				islocal = TRUE;
-				sender = newsender; /* choose preparse result */
-				break;
-			    default:
-				islocal = islocalhost(target);
-				sender = newsender; /* choose preparse result */
-				break;
-			    }
-			}
 		    }
 		}
 		break;
@@ -1898,6 +1869,98 @@ process_args(args, restrict)
     return;
 }
 
+void
+check_sender(from_spool)
+    int from_spool;			/* from the spoolfile args? */
+{
+    char *newsender;
+    char *error;			/* an error message */
+
+    DEBUG2(DBG_MAIN_MID, "check_sender(): checking %s sender address: '%v'\n",
+	   from_spool ? "spool" : "command-line",
+	   sender);
+
+    /*
+     * preparse_address() is destructive but we want it to be to strip
+     * unnecessary angle brackets, etc.
+     */
+    newsender = preparse_address(sender, &error);
+    if (! newsender) {
+	if (errfile) {
+	    write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+		      "validation error in sender address '%v': %s\n",
+		      sender, error);
+	}
+	if (!from_spool) {
+	    exit(EX_USAGE);
+	}
+	sender = "MAILER-DAEMON";
+	islocal = FALSE;		/* assumptions... */
+    } else {
+	char *target;
+	int sender_type;
+	char *tmpaddr;
+
+	sender = newsender;		/* choose preparse result by default */
+	tmpaddr = COPY_STRING(sender);	/* parse_address() is destructive */
+	sender_type = parse_address(tmpaddr, &target, &error, (int *) NULL);
+	switch (sender_type) {
+	case FAIL:
+	    write_log(WRITE_LOG_TTY | WRITE_LOG_PANIC,
+		      "syntax error in sender address '%v': %v\n",
+		      sender, error);
+	    if (!from_spool) {
+		exit(EX_USAGE);
+	    }
+	    islocal = FALSE;		/* assumptions... */
+	    sender = "MAILER-DAEMON";
+	    break;
+	case LOCAL:
+	    islocal = TRUE;
+#if 0
+	    if (!from_spool) {
+		/*
+		 * XXX only "trusted" users should be allowed to specify anyone
+		 * but themselves!!!
+		 */
+	    }
+#endif
+	    break;
+	case MAILBOX:
+	    /* XXX should we also do this test if UUCP_ROUTE && one hop */
+	    islocal = islocalhost(target);
+	    /* XXX should we allow root to set non-local addr from cmd-line? */
+	    if (!islocal && !from_spool) {
+		dprintf(errfile,
+			"%s: sender address '%v' is not a local address!\n",
+			program, sender);
+		exit(EX_USAGE);
+	    }
+#if 0
+	    if (islocal && !from_spool) {
+		/*
+		 * XXX only "trusted" users should be allowed to specify anyone
+		 * but themselves!!!
+		 */
+	    }
+#endif
+	    break;
+	default:
+	    if (errfile) {
+		dprintf(errfile,
+			"%s: sender address '%v' has invalid form\n",
+			program, sender);
+	    }
+	    if (!from_spool) {
+		exit(EX_USAGE);
+	    }
+	    islocal = FALSE;		/* assumptions... */
+	    break;
+	}
+	xfree(tmpaddr);
+    }
+}
+
 void
 process_recipients()
 {
