@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_119:modes.c,v 1.175 2004/08/23 23:19:17 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_120:modes.c,v 1.176 2004/08/27 06:52:47 woods Exp"
  */
 
 /*
@@ -3035,6 +3035,9 @@ read_and_process_message()
 
     /* process arguments from the spool file */
     process_args(argv, FALSE);
+    if (sender_is_trusted) {
+	check_sender(TRUE);
+    }
     process_recipients();
 
     /* perform delivery */
