@@ -1,5 +1,5 @@
 /*
-#ident	"@(#)smail/src:RELEASE-3_2_0_119:queue.c,v 1.78 2004/08/17 19:55:27 woods Exp"
+#ident	"@(#)smail/src:RELEASE-3_2_0_120:queue.c,v 1.79 2004/08/27 06:53:12 woods Exp"
  */
 
 /*
@@ -964,7 +964,7 @@ read_message()
     if (sender && sender_is_trusted) {
 	char *error;			/* temp to store error message */
 
-	islocal = parse_address(sender, (char **) NULL, &error, (int *) NULL) == LOCAL;
+	islocal = (parse_address(sender, (char **) NULL, &error, (int *) NULL) == LOCAL);
     }
 
     /*
@@ -1036,7 +1036,7 @@ read_message()
     /*
      * if the sender isn't known by now, then use the login user, or
      * postmaster if nothing else is available.  This may be overridden
-     * later with a -f or -r flag.
+     * later if a -f or -r flag is in argv.
      */
     if (sender == NULL) {
 	if (ls[0]) {
